@@ -38,7 +38,8 @@ class Esp32Matter(matter_device_base.MatterDeviceBase):
   DETECT_MATCH_CRITERIA = {
       detect_criteria.PigweedQuery.IS_MATTER: True,
       detect_criteria.PigweedQuery.MANUFACTURER_NAME:
-          r"(silicon(_| )labs|1a86)",
+      # CH9102F model has an empty string for MANUFACTURER_NAME
+          r"(silicon(_| )labs|1a86|)",
       detect_criteria.PigweedQuery.PRODUCT_NAME:
           r"(cp2104 usb to uart bridge controller|usb single serial)",
   }
